==> igniteui-react-layouts-18.0.0.tgz: package/esm5/lib/igr-list-panel-item-model.js <==
import { ListPanelItemModel as ListPanelItemModel_internal } from "./ListPanelItemModel";
import { ensureBool } from "igniteui-react-core";
var IgrListPanelItemModel = /** @class */ /*@__PURE__*/ (function () {
    function IgrListPanelItemModel() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrListPanelItemModel.prototype.createImplementation = function () {
        return new ListPanelItemModel_internal();
    };
    Object.defineProperty(IgrListPanelItemModel.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrListPanelItemModel.prototype.onImplementationCreated = function () {
    };
    IgrListPanelItemModel.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrListPanelItemModel.prototype, "dataRow", {
        get: function () {
            return this.i.l;
        },
        set: function (v) {
            this.i.l = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrListPanelItemModel.prototype, "rowHeight", {
        get: function () {
            return this.i.j;
        },
        set: function (v) {
            this.i.j = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrListPanelItemModel.prototype, "rowObject", {
        get: function () {
            return this.i.n;
        },
        set: function (v) {
            this.i.n = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrListPanelItemModel.prototype, "isModelDirty", {
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgrListPanelItemModel.prototype.findByName = function (name) {
        return null;
    };
    return IgrListPanelItemModel;
}());
export { IgrListPanelItemModel };

==> igniteui-react-layouts-18.2.0.tgz: package/esm5/lib/igr-list-panel-item-model.js <==
import { ListPanelItemModel as ListPanelItemModel_internal } from "./ListPanelItemModel";
import { ensureBool } from "igniteui-react-core";
var IgrListPanelItemModel = /** @class */ /*@__PURE__*/ (function () {
    function IgrListPanelItemModel() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrListPanelItemModel.prototype.createImplementation = function () {
        return new ListPanelItemModel_internal();
    };
    Object.defineProperty(IgrListPanelItemModel.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrListPanelItemModel.prototype.onImplementationCreated = function () {
    };
    IgrListPanelItemModel.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrListPanelItemModel.prototype, "dataRow", {
        get: function () {
            return this.i.m;
        },
        set: function (v) {
            this.i.m = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrListPanelItemModel.prototype, "rowHeight", {
        get: function () {
            return this.i.k;
        },
        set: function (v) {
            this.i.k = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrListPanelItemModel.prototype, "rowObject", {
        get: function () {
            return this.i.o;
        },
        set: function (v) {
            this.i.o = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrListPanelItemModel.prototype, "isModelDirty", {
        get: function () {
            return this.i.f;
        },
        set: function (v) {
            this.i.f = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgrListPanelItemModel.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    };
    return IgrListPanelItemModel;
}());
export { IgrListPanelItemModel };
